@@ -24,7 +24,7 @@ static void kate_packet_wrap_ogg(kate_packet *kp,const ogg_packet *op)
   kate_packet_wrap(kp,op->bytes,op->packet);
 }
 
-static void kate_packet_create_ogg(kate_packet *kp,ogg_packet *op,kate_encode_state *kes,int eos)
+static int kate_packet_create_ogg(kate_packet *kp,ogg_packet *op,kate_encode_state *kes,int eos)
 {
   op->b_o_s=(kes->packetno==0);
   op->e_o_s=eos;
@@ -32,8 +32,13 @@ static void kate_packet_create_ogg(kate_packet *kp,ogg_packet *op,kate_encode_st
   op->granulepos=kes->granulepos;
   op->bytes=kp->nbytes;
   op->packet=_ogg_malloc(kp->nbytes);
+  if (!op->packet) {
+    kate_free(kp->data);
+    return KATE_E_OUT_OF_MEMORY;
+  }
   memcpy(op->packet,kp->data,kp->nbytes);
   kate_free(kp->data);
+  return 0;
 }
 
 /**
@@ -52,8 +57,7 @@ int kate_ogg_encode_headers(kate_state *k,kate_comment *kc,ogg_packet *op)
   int ret=kate_encode_headers(k,kc,&kp);
   if (ret<0) return ret;
   if (ret>0) return ret; /* no more headers, no packet created */
-  kate_packet_create_ogg(&kp,op,k->kes,0);
-  return 0;
+  return kate_packet_create_ogg(&kp,op,k->kes,0);
 }
 
 /**
@@ -73,8 +77,7 @@ int kate_ogg_encode_text(kate_state *k,kate_float start_time,kate_float stop_tim
   kate_packet kp;
   int ret=kate_encode_text(k,start_time,stop_time,text,sz,&kp);
   if (ret<0) return ret;
-  kate_packet_create_ogg(&kp,op,k->kes,0);
-  return 0;
+  return kate_packet_create_ogg(&kp,op,k->kes,0);
 }
 
 /**
@@ -94,8 +97,7 @@ int kate_ogg_encode_text_raw_times(kate_state *k,kate_int64_t start_time,kate_in
   kate_packet kp;
   int ret=kate_encode_text_raw_times(k,start_time,stop_time,text,sz,&kp);
   if (ret<0) return ret;
-  kate_packet_create_ogg(&kp,op,k->kes,0);
-  return 0;
+  return kate_packet_create_ogg(&kp,op,k->kes,0);
 }
 
 /**
@@ -114,7 +116,10 @@ int kate_ogg_encode_repeat(kate_state *k,kate_float t,kate_float threshold,ogg_p
   kate_packet kp;
   int ret=kate_encode_repeat(k,t,threshold,&kp);
   if (ret<0) return ret;
-  if (ret>0) kate_packet_create_ogg(&kp,op,k->kes,0);
+  if (ret>0) {
+    int pret=kate_packet_create_ogg(&kp,op,k->kes,0);
+    if (pret<0) return pret;
+  }
   return ret;
 }
 
@@ -134,7 +139,10 @@ int kate_ogg_encode_repeat_raw_times(kate_state *k,kate_int64_t t,kate_int64_t t
   kate_packet kp;
   int ret=kate_encode_repeat_raw_times(k,t,threshold,&kp);
   if (ret<0) return ret;
-  if (ret>0) kate_packet_create_ogg(&kp,op,k->kes,0);
+  if (ret>0) {
+    int pret=kate_packet_create_ogg(&kp,op,k->kes,0);
+    if (pret<0) return pret;
+  }
   return ret;
 }
 
@@ -152,8 +160,7 @@ int kate_ogg_encode_keepalive(kate_state *k,kate_float t,ogg_packet *op)
   kate_packet kp;
   int ret=kate_encode_keepalive(k,t,&kp);
   if (ret<0) return ret;
-  kate_packet_create_ogg(&kp,op,k->kes,0);
-  return 0;
+  return kate_packet_create_ogg(&kp,op,k->kes,0);
 }
 
 /**
@@ -170,8 +177,7 @@ int kate_ogg_encode_keepalive_raw_times(kate_state *k,kate_int64_t t,ogg_packet
   kate_packet kp;
   int ret=kate_encode_keepalive_raw_times(k,t,&kp);
   if (ret<0) return ret;
-  kate_packet_create_ogg(&kp,op,k->kes,0);
-  return 0;
+  return kate_packet_create_ogg(&kp,op,k->kes,0);
 }
 
 /**
@@ -189,8 +195,7 @@ int kate_ogg_encode_finish(kate_state *k,kate_float t,ogg_packet *op)
   kate_packet kp;
   int ret=kate_encode_finish(k,t,&kp);
   if (ret<0) return ret;
-  kate_packet_create_ogg(&kp,op,k->kes,1);
-  return 0;
+  return kate_packet_create_ogg(&kp,op,k->kes,1);
 }
 
 /**
@@ -208,8 +213,7 @@ int kate_ogg_encode_finish_raw_times(kate_state *k,kate_int64_t t,ogg_packet *op
   kate_packet kp;
   int ret=kate_encode_finish_raw_times(k,t,&kp);
   if (ret<0) return ret;
-  kate_packet_create_ogg(&kp,op,k->kes,1);
-  return 0;
+  return kate_packet_create_ogg(&kp,op,k->kes,1);
 }
 
 /**
