@@ -29,6 +29,9 @@ typedef struct kate_tracker_internal {
   \param kin the tracker to initialize
   \param ki the kate_info structure for the stream
   \param ev the event to track
+  \returns 0 success
+  \returns KATE_E_INVALID_PARAMETER when kin, ki or ev is NULL.
+  \returns KATE_E_OUT_OF_MEMORY when unable to allocate memory.
   */
 int kate_tracker_init(kate_tracker *kin,const kate_info *ki,kate_const kate_event *ev)
 {
@@ -609,6 +612,8 @@ int kate_tracker_update(kate_tracker *kin,kate_float t,int window_w,int window_h
   \param glyph the index of the glyph to get the position of
   \param x will return the first coordinate of the position
   \param y will return the second coordinate of the position
+  \returns 0 success
+  \returns KATE_E_* error
   */
 int kate_tracker_get_text_path_position(kate_tracker *kin,size_t glyph,int *x,int *y)
 {
