@@ -35,6 +35,18 @@
 #include "kstrings.h"
 #include "kutil.h"
 
+/*
+** Inspiration : http://sourcefrog.net/weblog/software/languages/C/unused.html
+*/
+#ifdef UNUSED
+#elif defined (__GNUC__)
+#       define UNUSED(x) UNUSED_ ## x __attribute__ ((unused))
+#elif defined (__LCLINT__)
+#       define UNUSED(x) /*@unused@*/ x
+#else
+#       define UNUSED(x) x
+#endif
+
 typedef struct {
   kate_stream_set kate_streams;
   int n_streams;
@@ -54,7 +66,7 @@ typedef struct {
   void (*free_event_function_data)(void*);
 } ogg_parser_data;
 
-static int ogg_parser_on_page(kate_uintptr_t data,long offset,ogg_page *og)
+static int ogg_parser_on_page(kate_uintptr_t data,long UNUSED(offset),ogg_page *og)
 {
   ogg_parser_data *opd=(ogg_parser_data*)data;
   ogg_packet op;
@@ -210,7 +222,6 @@ static void print_help(const char *argv0)
 int main(int argc,char **argv)
 {
   size_t bytes_read;
-  int ret=-1;
   const char *input_filename=NULL;
   const char *output_filename=NULL;
   const char *output_filename_type=NULL;
@@ -346,7 +357,7 @@ int main(int argc,char **argv)
     /* raw Kate stream */
     kate_state k;
     FILE *fout;
-    int ret;
+    int ret=-1;
     char *buffer=NULL;
     ogg_int64_t bytes;
     int headers_written=0;
@@ -429,6 +440,7 @@ int main(int argc,char **argv)
   else
 #endif
   {
+    int ret=-1;
     signature_size=bytes_read;
 
     init_kate_stream_set(&opd.kate_streams);
@@ -443,6 +455,10 @@ int main(int argc,char **argv)
     opf.on_page=&ogg_parser_on_page;
     opf.on_hole=NULL;
     ret=parse_ogg_stream(fin,signature,signature_size,opf,(kate_uintptr_t)&opd);
+    if (ret<0) {
+      fprintf(stderr,"parse_ogg_stream failed: %d\n",ret);
+      /* continue anyway */
+    }
 
     /* Force EOS on truncated streams */
     for (n=0;n<opd.kate_streams.n_kate_streams;++n) {
