@@ -36,7 +36,7 @@
 #include "katedesc.h"
 
 extern int katedesc_parse(void);
-extern int katedesc_restart(FILE*);
+extern void katedesc_restart(FILE*);
 extern FILE *katedesc_in;
 extern FILE *katedesc_out;
 extern int nerrors;
