@@ -11,10 +11,13 @@
 #define KATE_klrc_h_GUARD
 
 struct lrc_data {
-  kate_float last_event_end_time;
+  kate_int64_t last_event_end_time;
 };
 
-extern void write_lrc_event(FILE *fout,void *data,const kate_event *ev,ogg_int64_t granpos,int event_index);
+extern void *new_lrc_data(void);
+extern void free_lrc_data(void*);
+
+extern void write_lrc_event(FILE *fout,void *data,const kate_event *ev,ogg_int64_t granpos);
 extern void write_lrc_end(FILE *fout);
 
 #endif
